@@ -35,6 +35,8 @@ mc5 <- function(ae, wr = FALSE) {
   gnls_la <- modl_lw <- gnls_lw <- gnls_rmse <- gnls_prob <- actp <- NULL
   modl_ac10 <- model_type <- NULL 
   
+  overwrite_osd <- FALSE
+  
   owarn <- getOption("warn")
   options(warn = 1)
   on.exit(options(warn = owarn))
@@ -82,6 +84,18 @@ mc5 <- function(ae, wr = FALSE) {
     ms <- ms[!mthd=='loec.coff']
   }
   
+  #special case where osd needs to be overwritten
+  if ('osd_coff_bmr' %in% ms$mthd) {
+    overwrite_osd <- TRUE
+    ms_osd_coff_bmr = ms[mthd=='osd_coff_bmr']
+    ms <- ms[!mthd=='osd_coff_bmr']
+  }
+
+  ## Extract methods that need to overwrite hitc and hit_val
+  ms_overwrite <- ms[grepl("ow_",mthd),]
+  ## Extract methods that don't overwrite
+  ms <- ms[!grepl("ow_",mthd),]
+  
   
   if (nrow(ms) == 0) {
     warning("No level 5 methods for AEID", ae, " -- cutoff will be 0.")
@@ -95,16 +109,19 @@ mc5 <- function(ae, wr = FALSE) {
   ## Determine final cutoff
   dat[ , coff := max(coff)]
   
+
   ## Check to see if we are using the v3 schema
   # currently can only use one coff
   if (check_tcpl_db_schema()) {
     cutoff <- max(dat$coff)
-    #can remove this once loading of data is working correctly
-    dat <- tcplQuery(paste0("SELECT  
-    `mc4`.`m4id`,    `mc4`.`aeid`,    `mc4`.`spid`,    `mc4`.`bmad`,    `mc4`.`resp_max`,    `mc4`.`resp_min`,    `mc4`.`max_mean`,    `mc4`.`max_mean_conc`,
-    `mc4`.`max_med`,    `mc4`.`max_med_conc`,    `mc4`.`logc_max`,    `mc4`.`logc_min`,    `mc4`.`nconc`,    `mc4`.`npts`,    `mc4`.`nrep`,    `mc4`.`nmed_gtbl`,
-    `mc4`.`tmpi`,	  `mc4_param`.`model`,    `mc4_param`.`model_param`,    `mc4_param`.`model_val`
-    FROM mc4 inner join mc4_param on mc4.m4id = mc4_param.m4id where mc4.aeid = ",ae,";"))
+
+    # before hitcalling overwrite osd value
+    if(overwrite_osd){
+      exprs <- lapply(mthd_funcs[ms_osd_coff_bmr$mthd], do.call, args = list())
+      fenv <- environment()
+      invisible(rapply(exprs, eval, envir = fenv))
+    }
+    
     # if we're using v3 schema we want to tcplfit2
     dat <- tcplHit2(dat, coff = cutoff)
   } else {
@@ -346,6 +363,15 @@ mc5 <- function(ae, wr = FALSE) {
   dat <- dat[ , .SD, .SDcols = outcols]
   }
   
+  
+  # apply overwrite methods
+  if (nrow(ms_overwrite) > 0) {
+    exprs <- lapply(mthd_funcs[ms_overwrite$mthd], do.call, args = list())
+    fenv <- environment()
+    invisible(rapply(exprs, eval, envir = fenv))
+  }
+  
+  
   ttime <- round(difftime(Sys.time(), stime, units = "sec"), 2)
   ttime <- paste(unclass(ttime), units(ttime))
   cat("Processed L5 AEID", ae, " (", nrow(dat), 
